@@ -157,12 +157,18 @@ class Connection:
             kwargs["timeout"] = self.timeout
         return kwargs
 
-    def do_put_request(self, url, data=None, allowable_response_status_codes=(200,), **kwargs):
+    def do_put_request(self, url, data=None, allowable_response_status_codes=(200,), retries=None, retry_delay=None,
+                       **kwargs):
         assert url is not None
         session_put_kwargs = self._get_requests_kwargs()
         session_put_kwargs.update(kwargs)
 
-        retries = self._retries
+        if retries is None:
+            retries = self._retries
+
+        if retry_delay is None:
+            retry_delay = self._retry_delay
+
         while True:
             try:
                 try:
@@ -182,14 +188,19 @@ class Connection:
                     raise e
 
                 retries -= 1
-                self.interruptable_sleep(self._retry_delay)
+                self.interruptable_sleep(retry_delay)
 
-    def do_get_request(self, url, allowable_response_status_codes=(200, 404), **kwargs):
+    def do_get_request(self, url, allowable_response_status_codes=(200, 404), retries=None, retry_delay=None, **kwargs):
         assert url is not None
         session_get_kwargs = self._get_requests_kwargs()
         session_get_kwargs.update(kwargs)
 
-        retries = self._retries
+        if retries is None:
+            retries = self._retries
+
+        if retry_delay is None:
+            retry_delay = self._retry_delay
+
         while True:
             try:
                 try:
@@ -209,14 +220,19 @@ class Connection:
                     raise e
 
                 retries -= 1
-                self.interruptable_sleep(self._retry_delay)
+                self.interruptable_sleep(retry_delay)
 
-    def do_head_request(self, url, allowable_response_status_codes=(200, 404), **kwargs):
+    def do_head_request(self, url, allowable_response_status_codes=(200, 404), retries=None, retry_delay=None, **kwargs):
         assert url is not None
         session_get_kwargs = self._get_requests_kwargs()
         session_get_kwargs.update(kwargs)
 
-        retries = self._retries
+        if retries is None:
+            retries = self._retries
+
+        if retry_delay is None:
+            retry_delay = self._retry_delay
+
         while True:
             try:
                 try:
@@ -236,14 +252,20 @@ class Connection:
                     raise e
 
                 retries -= 1
-                self.interruptable_sleep(self._retry_delay)
+                self.interruptable_sleep(retry_delay)
 
-    def do_options_request(self, url, allowable_response_status_codes=(200, 404), **kwargs):
+    def do_options_request(self, url, allowable_response_status_codes=(200, 404), retries=None, retry_delay=None,
+                           **kwargs):
         assert url is not None
         session_get_kwargs = self._get_requests_kwargs()
         session_get_kwargs.update(kwargs)
 
-        retries = self._retries
+        if retries is None:
+            retries = self._retries
+
+        if retry_delay is None:
+            retry_delay = self._retry_delay
+
         while True:
             try:
                 try:
@@ -263,14 +285,19 @@ class Connection:
                     raise e
 
                 retries -= 1
-                self.interruptable_sleep(self._retry_delay)
+                self.interruptable_sleep(retry_delay)
 
-    def do_post_request(self, url, allowable_response_status_codes=(200,), **kwargs):
+    def do_post_request(self, url, allowable_response_status_codes=(200,), retries=None, retry_delay=None, **kwargs):
         assert url is not None
         session_post_kwargs = self._get_requests_kwargs()
         session_post_kwargs.update(kwargs)
 
-        retries = self._retries
+        if retries is None:
+            retries = self._retries
+
+        if retry_delay is None:
+            retry_delay = self._retry_delay
+
         while True:
             try:
                 try:
@@ -290,14 +317,19 @@ class Connection:
                     raise e
 
                 retries -= 1
-                self.interruptable_sleep(self._retry_delay)
+                self.interruptable_sleep(retry_delay)
 
-    def do_delete_request(self, url, allowable_response_status_codes=(200,), **kwargs):
+    def do_delete_request(self, url, allowable_response_status_codes=(200,), retries=None, retry_delay=None, **kwargs):
         assert url is not None
         session_delete_kwargs = self._get_requests_kwargs()
         session_delete_kwargs.update(kwargs)
 
-        retries = self._retries
+        if retries is None:
+            retries = self._retries
+
+        if retry_delay is None:
+            retry_delay = self._retry_delay
+
         while True:
             try:
                 try:
@@ -317,7 +349,7 @@ class Connection:
                     raise e
 
                 retries -= 1
-                self.interruptable_sleep(self._retry_delay)
+                self.interruptable_sleep(retry_delay)
 
     def interruptable_sleep(self, sleep_time):
         self._close_has_been_called_event.wait(sleep_time)
@@ -471,7 +503,7 @@ class Connection:
     def get_dataset_indexes_url(self, dataset_id):
         return self.get_dataset_url(dataset_id) + "/indexes"
 
-    def restart_node(self, force=False):
+    def restart_node(self, force=False, **kwargs):
         """
             restarts the node via the admin api, it returns a dict {"message": "OK"} if successful
         """
@@ -485,19 +517,20 @@ class Connection:
 
         _allowable_response_status_codes = [200]
         restart_response = self.do_post_request(url, allowable_response_status_codes=_allowable_response_status_codes,
-                                                data=postdata)
+                                                data=postdata, **kwargs)
 
         validate_response_is_ok(restart_response, allowable_response_status_codes=_allowable_response_status_codes)
         return utils.parse_json_response(restart_response)
 
-    def get_systems(self, include_internal_systems=False):
+    def get_systems(self, include_internal_systems=False, **kwargs):
         systems = []
 
         # TODO: wrap in a utility-method and add error-detection
         request_params = {}
         if include_internal_systems:
             request_params["include-internal-systems"] = "true"
-        response = self.do_get_request(self.systems_url, allowable_response_status_codes=[200], params=request_params)
+        response = self.do_get_request(self.systems_url, allowable_response_status_codes=[200],
+                                       params=request_params, **kwargs)
         parsed_response = utils.parse_json_response(response)
 
         for system_json in parsed_response:
@@ -505,17 +538,17 @@ class Connection:
 
         return systems
 
-    def get_system(self, system_id):
-        response = self.do_get_request(self.get_system_url(system_id))
+    def get_system(self, system_id, **kwargs):
+        response = self.do_get_request(self.get_system_url(system_id), **kwargs)
         if response.status_code == 404:
             return None
         system_json = utils.parse_json_response(response)
         return System(self, system_json)
 
-    def get_models(self):
+    def get_models(self, **kwargs):
         models = []
 
-        response = self.do_get_request(self.models_url, allowable_response_status_codes=[200])
+        response = self.do_get_request(self.models_url, allowable_response_status_codes=[200], **kwargs)
         parsed_response = utils.parse_json_response(response)
 
         for model_json in parsed_response:
@@ -523,39 +556,39 @@ class Connection:
 
         return models
 
-    def get_model(self, model_id):
-        response = self.do_get_request(self.get_model_url(model_id))
+    def get_model(self, model_id, **kwargs):
+        response = self.do_get_request(self.get_model_url(model_id), **kwargs)
         if response.status_code == 404:
             return None
         model_json = utils.parse_json_response(response)
         return Model(self, model_json)
 
-    def get_systemconfigs(self):
-        response = self.do_get_request(self.systemconfigs_url, allowable_response_status_codes=[200])
+    def get_systemconfigs(self, **kwargs):
+        response = self.do_get_request(self.systemconfigs_url, allowable_response_status_codes=[200], **kwargs)
         return utils.parse_json_response(response)
 
-    def get_stats(self):
+    def get_stats(self, **kwargs):
         """
         :return: A nested dict with metrics.
         """
-        stats_response = self.do_get_request(self.stats_url, allowable_response_status_codes=[200])
+        stats_response = self.do_get_request(self.stats_url, allowable_response_status_codes=[200], **kwargs)
         return utils.parse_json_response(stats_response)
 
-    def get_status(self):
+    def get_status(self, **kwargs):
         """
         :return: A dict with various status-information (disk-usage, etc.)
         """
-        status_response = self.do_get_request(self.status_url)
+        status_response = self.do_get_request(self.status_url, **kwargs)
         return utils.parse_json_response(status_response)
 
-    def get_ping(self):
+    def get_ping(self, **kwargs):
         """
         :return: A dict with {"status": "running"} if successful
         """
-        status_response = self.do_get_request(self.ping_url)
+        status_response = self.do_get_request(self.ping_url, **kwargs)
         return utils.parse_json_response(status_response)
 
-    def get_datasets(self, include_internal_datasets=True, verbose=False):
+    def get_datasets(self, include_internal_datasets=True, verbose=False, **kwargs):
         # Note: the default for getting datasets is to get all
         # including the internal ones
         # This is opposite behaviour to pipes/systems
@@ -565,20 +598,21 @@ class Connection:
             params["include-internal-datasets"] = include_internal_datasets
         if verbose:
             params["verbose"] = verbose
-        response = self.do_get_request(self.datasets_url, allowable_response_status_codes=[200], params=params)
+        response = self.do_get_request(self.datasets_url, allowable_response_status_codes=[200],
+                                       params=params, **kwargs)
         parsed_response = utils.parse_json_response(response)
         for dataset_json in parsed_response:
             datasets.append(Dataset(self, dataset_json))
         return datasets
 
-    def get_dataset(self, dataset_id):
-        response = self.do_get_request(self.get_dataset_url(dataset_id), )
+    def get_dataset(self, dataset_id, **kwargs):
+        response = self.do_get_request(self.get_dataset_url(dataset_id), **kwargs)
         if response.status_code == 404:
             return None
         dataset_json = utils.parse_json_response(response)
         return Dataset(self, dataset_json)
 
-    def get_pipes(self, include_internal_pipes=False):
+    def get_pipes(self, include_internal_pipes=False, **kwargs):
         pipes = []
 
         # TODO: wrap in a utility-method and add error-detection
@@ -587,7 +621,7 @@ class Connection:
             request_params["include-internal-pipes"] = "true"
         response = self.do_get_request(self.pipes_url,
                                        allowable_response_status_codes=[200],
-                                       params=request_params
+                                       params=request_params, **kwargs
                                        )
 
         parsed_response = utils.parse_json_response(response)
@@ -596,26 +630,26 @@ class Connection:
             pipes.append(Pipe(self, pipe_json))
         return pipes
 
-    def get_pipe(self, pipe_id):
+    def get_pipe(self, pipe_id, **kwargs):
         # TODO: wrap in a utility-method and add error-detection
-        response = self.do_get_request(self.get_pipe_url(pipe_id))
+        response = self.do_get_request(self.get_pipe_url(pipe_id), **kwargs)
         if response.status_code == 404:
             return None
         pipe_json = utils.parse_json_response(response)
         return Pipe(self, pipe_json)
 
-    def get_pipe_schema_def(self, pipe_id, sample_size=1000, keys_only=False):
+    def get_pipe_schema_def(self, pipe_id, sample_size=1000, keys_only=False, **kwargs):
         # TODO: wrap in a utility-method and add error-detection
-        response = self.do_get_request(self.get_pipe_schema_def_url(pipe_id, sample_size, keys_only))
+        response = self.do_get_request(self.get_pipe_schema_def_url(pipe_id, sample_size, keys_only), **kwargs)
         if response.status_code == 404:
             return None
 
         return utils.parse_json_response(response)
 
-    def add_pipes(self, pipe_configs, force=False):
+    def add_pipes(self, pipe_configs, force=False, **kwargs):
         request_params = {"force": "true" if force else "false"}
         response = self.do_post_request(self.pipes_url, allowable_response_status_codes=[201, 409, 400],
-                                        json=pipe_configs, params=request_params)
+                                        json=pipe_configs, params=request_params, **kwargs)
 
         if response.status_code == 409:
             raise PipeAlreadyExists(response.text)
@@ -628,10 +662,10 @@ class Connection:
         pipes = [Pipe(self, pipe_json) for pipe_json in parsed_response]
         return pipes
 
-    def add_systems(self, system_configs, force=False):
+    def add_systems(self, system_configs, force=False, **kwargs):
         request_params = {"force": "true" if force else "false"}
         response = self.do_post_request(self.systems_url, allowable_response_status_codes=[201, 409, 400],
-                                        json=system_configs, params=request_params)
+                                        json=system_configs, params=request_params, **kwargs)
 
         if response.status_code == 409:
             raise SystemAlreadyExists(response.text)
@@ -644,9 +678,9 @@ class Connection:
         systems = [System(self, system_json) for system_json in parsed_response]
         return systems
 
-    def add_models(self, model_configs):
+    def add_models(self, model_configs, **kwargs):
         response = self.do_post_request(self.models_url, allowable_response_status_codes=[201, 409, 400],
-                                        json=model_configs)
+                                        json=model_configs, **kwargs)
 
         parsed_response = utils.parse_json_response(response)
 
@@ -656,129 +690,133 @@ class Connection:
         models = [Model(self, model_json) for model_json in parsed_response]
         return models
 
-    def get_logs(self):
+    def get_logs(self, **kwargs):
         logs = []
 
         # TODO: wrap in a utility-method and add error-detection
-        response = self.do_get_request(self.logs_url, allowable_response_status_codes=[200])
+        response = self.do_get_request(self.logs_url, allowable_response_status_codes=[200], **kwargs)
         parsed_response = utils.parse_json_response(response)
 
         for log_json in parsed_response:
             logs.append(Log(self, log_json))
         return logs
 
-    def get_log_content(self, log_id):
+    def get_log_content(self, log_id, **kwargs):
         """This returns a stream with the content of the specified logfile"""
         # TODO: wrap in a utility-method and add error-detection
-        response = self.do_get_request(self.get_log_url(log_id), stream=True)
+        response = self.do_get_request(self.get_log_url(log_id), stream=True, **kwargs)
         if response.status_code == 404:
             return None
         return response.raw
 
-    def get_metadata(self):
+    def get_metadata(self, **kwargs):
         """Gets the current metadata for the node"""
-        response = self.do_get_request(self.node_metadata_url)
+        response = self.do_get_request(self.node_metadata_url, **kwargs)
         return utils.parse_json_response(response)
 
-    def set_metadata(self, metadata):
+    def set_metadata(self, metadata, **kwargs):
         """Replaces the metadata for the node with the specified dictionary"""
-        self.do_put_request(self.node_metadata_url, allowable_response_status_codes=[200], json=metadata)
+        self.do_put_request(self.node_metadata_url, allowable_response_status_codes=[200], json=metadata, **kwargs)
 
-    def get_namespaces(self):
+    def get_namespaces(self, **kwargs):
         """Gets the current metadata for the node"""
-        response = self.do_get_request(self.node_namespaces_url, allowable_response_status_codes=[200])
+        response = self.do_get_request(self.node_namespaces_url, allowable_response_status_codes=[200], **kwargs)
         return utils.parse_json_response(response)
 
-    def get_secrets(self, include_internal_secrets=False):
+    def get_secrets(self, include_internal_secrets=False, **kwargs):
         """This returns a list with the names of the secrets."""
         request_params = {}
         if include_internal_secrets:
             request_params["include-internal-secrets"] = "true"
 
-        response = self.do_get_request(self.secrets_url, allowable_response_status_codes=[200], params=request_params)
+        response = self.do_get_request(self.secrets_url, allowable_response_status_codes=[200], params=request_params,
+                                       **kwargs)
         secrets_info = utils.parse_json_response(response)
         return secrets_info
 
-    def get_secrets_values(self):
+    def get_secrets_values(self, **kwargs):
         """This returns a dict with secretname=>secretvalue mappings. This is only available for nodes that
         are running in ci-test mode. In addition, the user has to have the "SystemAdmin" role."""
         request_params = {}
         response = self.do_get_request(self.secrets_values_url, allowable_response_status_codes=[200],
-                                       params=request_params)
+                                       params=request_params, **kwargs)
         secrets_info = utils.parse_json_response(response)
         return secrets_info
 
-    def put_secrets(self, secrets_content, dont_encrypt=False):
+    def put_secrets(self, secrets_content, dont_encrypt=False, **kwargs):
         encrypt = dont_encrypt and "false" or "true"
         response = self.do_put_request(self.secrets_url, allowable_response_status_codes=[200],
-                                       json=secrets_content, params=dict(encrypt=encrypt))
+                                       json=secrets_content, params=dict(encrypt=encrypt), **kwargs)
 
         secrets_info = utils.parse_json_response(response)
         return secrets_info
 
-    def post_secrets(self, secrets_content, dont_encrypt=False):
+    def post_secrets(self, secrets_content, dont_encrypt=False, **kwargs):
         encrypt = dont_encrypt and "false" or "true"
         response = self.do_post_request(self.secrets_url, allowable_response_status_codes=[200],
-                                        json=secrets_content, params=dict(encrypt=encrypt))
+                                        json=secrets_content, params=dict(encrypt=encrypt), **kwargs)
 
         secrets_info = utils.parse_json_response(response)
         return secrets_info
 
-    def delete_secret(self, key):
-        response = self.do_delete_request(self.get_secret_url(key), allowable_response_status_codes=[200])
+    def delete_secret(self, key, **kwargs):
+        response = self.do_delete_request(self.get_secret_url(key), allowable_response_status_codes=[200], **kwargs)
         secrets_info = utils.parse_json_response(response)
         return secrets_info
 
-    def get_env_vars(self):
-        response = self.do_get_request(self.env_vars_url, allowable_response_status_codes=[200])
+    def get_env_vars(self, **kwargs):
+        response = self.do_get_request(self.env_vars_url, allowable_response_status_codes=[200], **kwargs)
         env_vars_info = utils.parse_json_response(response)
         return env_vars_info
 
-    def put_env_vars(self, env_vars_content):
-        response = self.do_put_request(self.env_vars_url, allowable_response_status_codes=[200], json=env_vars_content)
+    def put_env_vars(self, env_vars_content, **kwargs):
+        response = self.do_put_request(self.env_vars_url, allowable_response_status_codes=[200],
+                                       json=env_vars_content, **kwargs)
 
         env_vars_info = utils.parse_json_response(response)
         return env_vars_info
 
-    def post_env_vars(self, env_vars_content):
-        response = self.do_post_request(self.env_vars_url, allowable_response_status_codes=[200], json=env_vars_content)
+    def post_env_vars(self, env_vars_content, **kwargs):
+        response = self.do_post_request(self.env_vars_url, allowable_response_status_codes=[200], json=env_vars_content,
+                                        **kwargs)
 
         env_vars_info = utils.parse_json_response(response)
         return env_vars_info
 
-    def delete_env_var(self, key):
-        response = self.do_delete_request(self.get_env_var_url(key), allowable_response_status_codes=[200])
+    def delete_env_var(self, key, **kwargs):
+        response = self.do_delete_request(self.get_env_var_url(key), allowable_response_status_codes=[200], **kwargs)
         env_vars_info = utils.parse_json_response(response)
         return env_vars_info
 
-    def get_license(self):
+    def get_license(self, **kwargs):
         """Gets the current license info for the node"""
-        response = self.do_get_request(self.node_license_url)
+        response = self.do_get_request(self.node_license_url, **kwargs)
         license_info = utils.parse_json_response(response)
         return license_info
 
-    def set_license(self, license_key_content):
+    def set_license(self, license_key_content, **kwargs):
         """Replaces the license for the node with the specified license key"""
         response = self.do_put_request(self.node_license_url, allowable_response_status_codes=[200],
-                                       data=license_key_content)
+                                       data=license_key_content, **kwargs)
         license_info = utils.parse_json_response(response)
         return license_info
 
-    def delete_metadata(self):
+    def delete_metadata(self, **kwargs):
         """Deleted all metadata for the node"""
-        self.do_delete_request(self.node_metadata_url, allowable_response_status_codes=[200])
+        self.do_delete_request(self.node_metadata_url, allowable_response_status_codes=[200], **kwargs)
 
-    def get_config(self, config_group=None):
+    def get_config(self, config_group=None, **kwargs):
         """Returns the configuration of the sesam node.
         :param config_group: The config-group to get the config from. The default is None, meaning the main config
                       of the node.
         """
-        response = self.do_get_request(self.get_config_url(config_group), allowable_response_status_codes=[200])
+        response = self.do_get_request(self.get_config_url(config_group), allowable_response_status_codes=[200],
+                                       **kwargs)
         utils.validate_equal_case_insensitive(response.headers["Content-Type"], "application/json")
         config = utils.parse_json_response(response)
         return config
 
-    def get_config_history(self, entity_id, since=None, limit=None, reverse=None):
+    def get_config_history(self, entity_id, since=None, limit=None, reverse=None, **kwargs):
         """Returns the history of the configuration entity of the sesam node.
 
         :param entity_id: the id of the entity
@@ -805,23 +843,24 @@ class Connection:
         if reverse and reverse is True:
             request_params["reverse"] = reverse
 
-        response = self.do_get_request(url, allowable_response_status_codes=[200], params=request_params)
+        response = self.do_get_request(url, allowable_response_status_codes=[200], params=request_params, **kwargs)
         utils.validate_equal_case_insensitive(response.headers["Content-Type"], "application/json")
         config = utils.parse_json_response(response)
 
         return config
 
-    def get_config_as_json_string(self, config_group=None):
+    def get_config_as_json_string(self, config_group=None, **kwargs):
         """Returns the configuration of the sesam node as a json-string, using the same formatting
         as the raw server response.
         :param config_group: The config-group to get the config from. The default is None, meaning the main config
                       of the node.
         """
-        response = self.do_get_request(self.get_config_url(config_group), allowable_response_status_codes=[200])
+        response = self.do_get_request(self.get_config_url(config_group), allowable_response_status_codes=[200],
+                                       **kwargs)
         utils.validate_equal_case_insensitive(response.headers["Content-Type"], "application/json")
         return response.content.decode("utf-8")
 
-    def get_config_as_zip(self, config_group=None):
+    def get_config_as_zip(self, config_group=None, **kwargs):
         """Returns the configuration of the sesam node as a zip-archive with separate files for each pipe, system,
         etc.
         :param config_group: The config-group to get the config from. The default is None, meaning the main config
@@ -832,7 +871,7 @@ class Connection:
         """
         response = self.do_get_request(self.get_config_url(config_group),
                                        allowable_response_status_codes=[200],
-                                       headers={"ACCEPT": "application/zip"},
+                                       headers={"ACCEPT": "application/zip"}, **kwargs
                                        )
         utils.validate_equal_case_insensitive(response.headers["Content-Type"], "application/zip")
         return response.content
@@ -840,7 +879,7 @@ class Connection:
     def upload_config(self, config,
                       config_group=None,
                       force=False,
-                      _use_multipart_form_data=True):
+                      _use_multipart_form_data=True, **kwargs):
         """
         Uploads the specified configuration. The new configuration will replace any existing
         configuration. Any existing configuration entities that are not in the new configuration will
@@ -912,7 +951,7 @@ class Connection:
                                                params=request_params,
                                                # we will deal with any 400-errors later
                                                allowable_response_status_codes=[200, 400],
-                                               files=files)
+                                               files=files, **kwargs)
             else:
                 # We want to put the config content directly in the response body.
                 data = theconfigfile.read()
@@ -925,7 +964,7 @@ class Connection:
                                                params=request_params,
                                                # we will deal with any 400-errors later
                                                allowable_response_status_codes=[200, 400],
-                                               headers={"Content-Type": content_type})
+                                               headers={"Content-Type": content_type}, **kwargs)
 
         finally:
             if theconfigfile_must_be_closed:
@@ -940,7 +979,7 @@ class Connection:
 
         return parsed_response
 
-    def get_access_control_list(self, acl_path):
+    def get_access_control_list(self, acl_path, **kwargs):
         """Retrieves the specified acl. The acl_path is the relative part of the url to the acl.
 
         Examples:
@@ -949,47 +988,47 @@ class Connection:
             "dataset_prototype"
         """
         acl_url = self.sesamapi_base_url + "permissions/" + acl_path
-        response = self.do_get_request(acl_url, allowable_response_status_codes=[200])
+        response = self.do_get_request(acl_url, allowable_response_status_codes=[200], **kwargs)
         utils.validate_equal_case_insensitive(response.headers["Content-Type"], "application/json")
         acl = utils.parse_json_response(response)
         return acl
 
-    def set_access_control_list(self, acl_path, acl):
+    def set_access_control_list(self, acl_path, acl, **kwargs):
         """Uploads the specified acl. The acl_path is the relative part of the url to the acl (see
         the get_access_control_list() method for examples.
         """
         acl_url = self.sesamapi_base_url + "permissions/" + acl_path
-        self.do_put_request(acl_url, allowable_response_status_codes=[200], json=acl)
+        self.do_put_request(acl_url, allowable_response_status_codes=[200], json=acl, **kwargs)
 
-    def login(self, email, password):
+    def login(self, email, password, **kwargs):
         login_url = self.sesamapi_base_url + "jwt"
 
         response = self.do_post_request(login_url, allowable_response_status_codes=[200],
-                                        data={"email": email, "password": password})
+                                        data={"email": email, "password": password}, **kwargs)
 
         jwt = response.text
 
         return jwt
 
-    def get_backup(self, backup_id):
+    def get_backup(self, backup_id, **kwargs):
         url = self.sesamapi_base_url + "backups/" + backup_id
-        response = self.do_get_request(url, allowable_response_status_codes=[200])
+        response = self.do_get_request(url, allowable_response_status_codes=[200], **kwargs)
         backup_info = response.json()
         return backup_info
 
-    def get_backups(self):
+    def get_backups(self, **kwargs):
         url = self.sesamapi_base_url + "backups"
-        response = self.do_get_request(url, allowable_response_status_codes=[200])
+        response = self.do_get_request(url, allowable_response_status_codes=[200], **kwargs)
         backups = response.json()
         return backups
 
-    def trigger_backup(self):
+    def trigger_backup(self, **kwargs):
         url = self.sesamapi_base_url + "backups"
-        response = self.do_post_request(url, allowable_response_status_codes=[200])
+        response = self.do_post_request(url, allowable_response_status_codes=[200], **kwargs)
         backup_info = response.json()
         return backup_info
 
-    def wait_for_backup_to_finish(self, backup_id, timeout=60, poll_interval=0.5):
+    def wait_for_backup_to_finish(self, backup_id, timeout=60, poll_interval=0.5, **kwargs):
         """Utility method for waiting until the specified backup is no longer running.
 
         :param timeout: The maximum time to wait for the backup to stop running. If the timeout is exceeded,
@@ -998,7 +1037,7 @@ class Connection:
         starttime = time.monotonic()
         while True:
             url = self.sesamapi_base_url + "backups/" + backup_id
-            response = self.do_get_request(url, allowable_response_status_codes=[200])
+            response = self.do_get_request(url, allowable_response_status_codes=[200], **kwargs)
             backup_info = response.json()
             if backup_info["status"] != "running":
                 break
@@ -1010,7 +1049,7 @@ class Connection:
 
             time.sleep(poll_interval)
 
-    def get_api_info(self):
-        response = self.do_get_request(self.sesamapi_base_url, allowable_response_status_codes=[200])
+    def get_api_info(self, **kwargs):
+        response = self.do_get_request(self.sesamapi_base_url, allowable_response_status_codes=[200], **kwargs)
         info = response.json()
         return info
