@@ -7,7 +7,6 @@ import logging
 import os.path
 from html.parser import HTMLParser
 
-import jwt
 import requests.exceptions
 import sys
 
@@ -787,33 +786,6 @@ def main():
                 # This command is special and does not use a jwt token.
                 jwt_auth_token = None
 
-            if jwt_auth_token is not None:
-                decoded_jwt = None
-                try:
-                    decoded_jwt = jwt.decode(jwt_auth_token, verify=False)
-                except jwt.DecodeError as e:
-                    if got_jwt_from_commandline_argument:
-                        main_utils.exit_with_error("The JWT authorization token in the '%s' file is invalid: '%s'." % (
-                            jwt_filename, e))
-                    else:
-                        main_utils.exit_with_error(
-                            ("The sesam client is logged in (that is, there is a JWT authorization token in the "
-                             "'%s' file), but the JWT authorization token is invalid. Tip: do a 'sesam logout'"
-                             "and a 'sesam login' and try again. The JWT decode error was: '%s'.") % (
-                                get_configfilename(), e))
-                expire_time = decoded_jwt["exp"]
-                remaining_time_until_expiration = int(expire_time - time.time())
-                if remaining_time_until_expiration < 0:
-                    if got_jwt_from_commandline_argument:
-                        main_utils.exit_with_error(
-                            "The JWT authorization token in the '%s' file expired %d seconds ago." % (
-                               jwt_filename, -remaining_time_until_expiration))
-                    else:
-                        main_utils.exit_with_error(
-                            ("The sesam client is logged in (that is, there is a JWT authorization token in the "
-                             "'%s' file), but the JWT authorization token expired %d seconds ago. Tip: do a new "
-                             "'sesam login' and try again.") % (get_configfilename(), -remaining_time_until_expiration))
-
             timeout = int(myconfigparser.get("server", "timeout", fallback="") or 30)
             connection = Connection(sesamapi_base_url=sesamapi_base_url,
                                     username=username,
