@@ -20,11 +20,12 @@ class Model(EntityBase):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
-    def delete(self):
+    def delete(self, **kwargs):
         """Deletes this system from the sesam-node.
         """
         url = self._connection.get_model_url(self.id)
-        response = self._connection.do_delete_request(url, allowable_response_status_codes=[200])
+        response = self._connection.do_delete_request(url, allowable_response_status_codes=[200],
+                                                      **kwargs)
         self.update_raw_jsondata(response.content.decode("utf-8"))
 
     @property
