@@ -61,7 +61,8 @@ class Pipe(EntityBase):
         return runtime.get("execution-dataset")
 
     def get_log_entities(self, since=None, limit=None, start=None, history=True, deleted=True, reverse=False,
-                         accept="application/json", expected_node_id=None, method="GET"):
+                         accept="application/json", expected_node_id=None, method="GET",
+                         **kwargs):
         """Returns the content of the execution dataset using the /pipes/{pipe}/log API """
         url = self._connection.get_pipe_log_url(self.id)
 
@@ -92,8 +93,8 @@ class Pipe(EntityBase):
         if request_func is None:
             raise AssertionError("Unsupported request-method '%s'!" % (method,))
 
-        response = request_func(url, allowable_response_status_codes=[200], stream=True,
-                                params=params, headers=headers)
+        response = request_func(url, allowable_response_status_codes=[200], stream=True, params=params,
+                                headers=headers, **kwargs)
 
         return entity_json.parse_json_stream(response.raw)
 
@@ -101,7 +102,7 @@ class Pipe(EntityBase):
     def runtime(self):
         return copy.deepcopy(self._raw_jsondata["runtime"])
 
-    def get_entities(self, since=None, limit=None):
+    def get_entities(self, since=None, limit=None, **kwargs):
         """This returns a generator for iterating over the entities of the source of this pipe.
         :param since:
         :param limit: The maximum number of entities to return. A value of None means return all the entities.
@@ -116,7 +117,7 @@ class Pipe(EntityBase):
 
         # The entities are streamed from the server, so we have to enable streaming here.
         response = self._connection.do_get_request(url, allowable_response_status_codes=[200],
-                                                   stream=True, params=params)
+                                                   stream=True, params=params, **kwargs)
 
         return entity_json.parse_json_stream(response.raw)
 
@@ -127,6 +128,7 @@ class Pipe(EntityBase):
                       previous_request_id=None,
                       is_last=None,
                       is_first=None,
+                      **kwargs
                       ):
         """This posts the specified entities to the pipe. This only works for pipes that has a source
         of the type 'http_endpoint'.
@@ -164,26 +166,26 @@ class Pipe(EntityBase):
                                                     allowable_response_status_codes=[200],
                                                     headers={"Content-Type": "application/json"},
                                                     params=params,
-                                                    data=entities_stream)
+                                                    data=entities_stream, **kwargs)
 
         return response.json()
 
-    def delete(self):
+    def delete(self, **kwargs):
         """Deletes this pipe from the sesam-node.
         """
         url = self._connection.get_pipe_url(self.id)
-        response = self._connection.do_delete_request(url, allowable_response_status_codes=[200])
+        response = self._connection.do_delete_request(url, allowable_response_status_codes=[200], **kwargs)
 
         self.update_raw_jsondata(response.content.decode("utf-8"))
 
-    def modify(self, pipe_config, force=False):
+    def modify(self, pipe_config, force=False, **kwargs):
         """Modifies the pipe with the specified configuration."""
         request_params = {"force": "true" if force else "false"}
         pipe_config = copy.deepcopy(pipe_config)
         response = self._connection.do_put_request(self._connection.get_pipe_config_url(self.id),
                                                    allowable_response_status_codes=[200, 400],
                                                    json=pipe_config,
-                                                   params=request_params)
+                                                   params=request_params, **kwargs)
 
         if response.status_code == 400:
             raise ConfigUploadFailed(response=response)
