@@ -75,9 +75,11 @@ class Pump(EntityBase):
 
             elapsedtime = time.monotonic() - starttime
             if elapsedtime > timeout:
+                self.pipe.update_raw_jsondata_from_url(self._connection.get_pipe_url(self.pipe.id))
                 raise TimeoutWhileWaitingForRunningPumpToFinishException(
-                    "Timed out while waiting for the pump to finish running! pump:\n%s" % (
-                        self.as_json(),))
+                    "Timed out while waiting for the pump to finish running! pipe:\n%s" % (
+                        self.pipe.as_json(),
+                    ))
 
             if verbosity > 0:
                 current_time = time.monotonic()
@@ -227,15 +229,18 @@ class Pump(EntityBase):
     def next_run(self):
         return parse_datetime(self._raw_jsondata["runtime"]["next-run"])
 
-    def disable(self):
-        """Disable this pump. This prevents the pump from being automatically run by the task scheduler"""
-        self._set_disabled_state(True)
+    def disable(self, comment=None):
+        """
+        Disable this pump. This prevents the pump from being automatically run by the task scheduler.
+        Can add comment parameter that shows up in execution log.
+        """
+        self._set_disabled_state(True, comment=comment)
 
     def enable(self):
         """Enable this pump."""
         self._set_disabled_state(False)
 
-    def _set_disabled_state(self, is_disabled):
+    def _set_disabled_state(self, is_disabled, comment=None):
         # Send a put-request to disable the pump
         if self.is_disabled != is_disabled:
             if is_disabled:
@@ -243,7 +248,13 @@ class Pump(EntityBase):
             else:
                 operation = "enable"
 
-            self.run_operation(operation, allowable_response_status_codes=frozenset([200]))
+            if operation == "disable" and comment is not None:
+                operation_parameters = { comment: comment}
+            else:
+                operation_parameters = None
+
+            self.run_operation(operation, operation_parameters=operation_parameters,
+                                allowable_response_status_codes=frozenset([200]))
 
             # Check that the "is-disabled"-attribute has been updated
             actual_is_disabled = self.is_disabled
